// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KEDUVOCDOCUMENT_VERSION_H
#define KEDUVOCDOCUMENT_VERSION_H

#define KEDUVOCDOCUMENT_VERSION_STRING "5.1.0"
#define KEDUVOCDOCUMENT_VERSION_MAJOR 5
#define KEDUVOCDOCUMENT_VERSION_MINOR 1
#define KEDUVOCDOCUMENT_VERSION_PATCH 0
#define KEDUVOCDOCUMENT_VERSION ((5<<16)|(1<<8)|(0))

#endif
